@@ -13,7 +13,7 @@
 #   limitations under the License.
 import warnings
 
-from collections.abc import Callable, Generator, Iterable, Sequence
+from collections.abc import Iterable, Sequence
 from typing import cast
 
 import numpy as np
@@ -33,10 +33,8 @@ from pytensor.graph.basic import (
     clone_get_equiv,
     equal_computations,
     graph_inputs,
-    walk,
 )
 from pytensor.graph.fg import FunctionGraph, Output
-from pytensor.graph.op import Op
 from pytensor.scalar.basic import Cast
 from pytensor.scan.op import Scan
 from pytensor.tensor.basic import _as_tensor_variable
@@ -56,17 +54,13 @@ from pymc.vartypes import continuous_types, isgenerator, typefilter
 
 PotentialShapeType = int | np.ndarray | Sequence[int | Variable] | TensorVariable
 
-
 __all__ = [
     "CallableTensor",
     "compile",
-    "compile_pymc",
     "cont_inputs",
     "convert_data",
-    "convert_generator_data",
     "convert_observed_data",
     "floatX",
-    "generator",
     "gradient",
     "hessian",
     "hessian_diag",
@@ -81,20 +75,10 @@ __all__ = [
 def convert_observed_data(data) -> np.ndarray | Variable:
     """Convert user provided dataset to accepted formats."""
     if isgenerator(data):
-        return convert_generator_data(data)
+        raise TypeError("Data passed to `observed` cannot be a generator.")
     return convert_data(data)
 
 
-def convert_generator_data(data) -> TensorVariable:
-    warnings.warn(
-        "Generator data is deprecated and we intend to remove it."
-        " If you disagree and need this, please get in touch via https://github.com/pymc-devs/pymc/issues.",
-        DeprecationWarning,
-        stacklevel=2,
-    )
-    return generator(data)
-
-
 def convert_data(data) -> np.ndarray | Variable:
     ret: np.ndarray | Variable
     if hasattr(data, "to_numpy") and hasattr(data, "isnull"):
@@ -177,41 +161,15 @@ def extract_obs_data(x: TensorVariable) -> np.ndarray:
             mask[mask_idx] = 1
             return np.ma.MaskedArray(array_data, mask)
 
+    from pymc.logprob.utils import rvs_in_graph
+
+    if not inputvars(x) and not rvs_in_graph(x):
+        cheap_eval_mode = Mode(linker="py", optimizer=None)
+        return x.eval(mode=cheap_eval_mode)
+
     raise TypeError(f"Data cannot be extracted from {x}")
 
 
-def walk_model(
-    graphs: Iterable[TensorVariable],
-    stop_at_vars: set[TensorVariable] | None = None,
-    expand_fn: Callable[[TensorVariable], Iterable[TensorVariable]] = lambda var: [],
-) -> Generator[TensorVariable, None, None]:
-    """Walk model graphs and yield their nodes.
-
-    Parameters
-    ----------
-    graphs
-        The graphs to walk.
-    stop_at_vars
-        A list of variables at which the walk will terminate.
-    expand_fn
-        A function that returns the next variable(s) to be traversed.
-    """
-    warnings.warn("walk_model will be removed in a future relase of PyMC", FutureWarning)
-
-    if stop_at_vars is None:
-        stop_at_vars = set()
-
-    def expand(var):
-        new_vars = expand_fn(var)
-
-        if var.owner and var not in stop_at_vars:
-            new_vars.extend(reversed(var.owner.inputs))
-
-        return new_vars
-
-    yield from walk(graphs, expand, bfs=False)
-
-
 def replace_vars_in_graphs(
     graphs: Iterable[Variable],
     replacements: dict[Variable, Variable],
@@ -601,12 +559,17 @@ def join_nonshared_inputs(
 class PointFunc:
     """Wraps so a function so it takes a dict of arguments instead of arguments."""
 
+    __slots__ = ("f",)
+
     def __init__(self, f):
         self.f = f
 
     def __call__(self, state):
         return self.f(**state)
 
+    def dprint(self, **kwrags):
+        return self.f.dprint(**kwrags)
+
 
 class CallableTensor:
     """Turns a symbolic variable with one input into a function that returns symbolic arguments with the one variable replaced with the input."""
@@ -625,98 +588,6 @@ class CallableTensor:
         return pytensor.clone_replace(self.tensor, {oldinput: input}, rebuild_strict=False)
 
 
-class GeneratorOp(Op):
-    """
-    Generator Op is designed for storing python generators inside pytensor graph.
-
-    __call__ creates TensorVariable
-        It has 2 new methods
-        - var.set_gen(gen): sets new generator
-        - var.set_default(value): sets new default value (None erases default value)
-
-    If generator is exhausted, variable will produce default value if it is not None,
-    else raises `StopIteration` exception that can be caught on runtime.
-
-    Parameters
-    ----------
-    gen: generator that implements __next__ (py3) or next (py2) method
-        and yields np.arrays with same types
-    default: np.array with the same type as generator produces
-    """
-
-    __props__ = ("generator",)
-
-    def __init__(self, gen, default=None):
-        warnings.warn(
-            "generator data is deprecated and will be removed in a future release", FutureWarning
-        )
-        from pymc.data import GeneratorAdapter
-
-        super().__init__()
-        if not isinstance(gen, GeneratorAdapter):
-            gen = GeneratorAdapter(gen)
-        self.generator = gen
-        self.set_default(default)
-
-    def make_node(self, *inputs):
-        gen_var = self.generator.make_variable(self)
-        return Apply(self, [], [gen_var])
-
-    def perform(self, node, inputs, output_storage, params=None):
-        if self.default is not None:
-            output_storage[0][0] = next(self.generator, self.default)
-        else:
-            output_storage[0][0] = next(self.generator)
-
-    def do_constant_folding(self, fgraph, node):
-        return False
-
-    __call__ = pytensor.config.change_flags(compute_test_value="off")(Op.__call__)
-
-    def set_gen(self, gen):
-        from pymc.data import GeneratorAdapter
-
-        if not isinstance(gen, GeneratorAdapter):
-            gen = GeneratorAdapter(gen)
-        if not gen.tensortype == self.generator.tensortype:
-            raise ValueError("New generator should yield the same type")
-        self.generator = gen
-
-    def set_default(self, value):
-        if value is None:
-            self.default = None
-        else:
-            value = np.asarray(value, self.generator.tensortype.dtype)
-            t1 = (False,) * value.ndim
-            t2 = self.generator.tensortype.broadcastable
-            if not t1 == t2:
-                raise ValueError("Default value should have the same type as generator")
-            self.default = value
-
-
-def generator(gen, default=None):
-    """
-    Create a generator variable with possibility to set default value and new generator.
-
-    If generator is exhausted variable will produce default value if it is not None,
-    else raises `StopIteration` exception that can be caught on runtime.
-
-    Parameters
-    ----------
-    gen: generator that implements __next__ (py3) or next (py2) method
-        and yields np.arrays with same types
-    default: np.array with the same type as generator produces
-
-    Returns
-    -------
-    TensorVariable
-        It has 2 new methods
-        - var.set_gen(gen): sets new generator
-        - var.set_default(value): sets new default value (None erases default value)
-    """
-    return GeneratorOp(gen, default)()
-
-
 def ix_(*args):
     """
     PyTensor np.ix_ analog.
@@ -1053,14 +924,6 @@ def compile(
     return pytensor_function
 
 
-def compile_pymc(*args, **kwargs):
-    warnings.warn(
-        "compile_pymc was renamed to compile. Old name will be removed in a future release of PyMC",
-        FutureWarning,
-    )
-    return compile(*args, **kwargs)
-
-
 def constant_fold(
     xs: Sequence[TensorVariable], raise_not_constant: bool = True
 ) -> tuple[np.ndarray | Variable, ...]:
@@ -1078,7 +941,7 @@ def constant_fold(
     """
     fg = FunctionGraph(outputs=xs, features=[ShapeFeature()], copy_inputs=False, clone=True)
 
-    # The default rewrite_graph includes a constand_folding that is not always applied.
+    # The default rewrite_graph includes a constant_folding that is not always applied.
     # We use an unconditional constant_folding as the last pass to ensure a thorough constant folding.
     rewrite_graph(fg)
     topo_unconditional_constant_folding.apply(fg)
