@@ -1,4 +1,4 @@
-#   Copyright 2024 The PyMC Developers
+#   Copyright 2024 - present The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ import warnings
 
 from abc import ABC, abstractmethod
 from collections.abc import Iterable, Mapping, Sequence
+from dataclasses import field
 from enum import IntEnum, unique
 from typing import Any
 
@@ -96,6 +97,7 @@ def infer_warn_stats_info(
 
 @dataclass_state
 class StepMethodState(DataClassState):
+    var_names: list[str] = field(metadata={"tensor_name": True, "frozen": True})
     rng: RandomGeneratorState
 
 
@@ -179,6 +181,20 @@ class BlockedStep(ABC, WithSamplingState):
             step.__newargs = (vars, *args), kwargs
             return step
 
+    @staticmethod
+    def _progressbar_config(n_chains=1):
+        columns = []
+        stats = {}
+
+        return columns, stats
+
+    @staticmethod
+    def _make_progressbar_update_functions():
+        def update_stats(step_stats):
+            return step_stats
+
+        return (update_stats,)
+
     # Hack for creating the class correctly when unpickling.
     def __getnewargs_ex__(self):
         return self.__newargs
@@ -280,9 +296,9 @@ class CompoundStep(WithSamplingState):
 
     @sampling_state.setter
     def sampling_state(self, state: DataClassState):
-        assert isinstance(
-            state, self._state_class
-        ), f"Invalid sampling state class {type(state)}. Expected {self._state_class}"
+        assert isinstance(state, self._state_class), (
+            f"Invalid sampling state class {type(state)}. Expected {self._state_class}"
+        )
         for method, state_method in zip(self.methods, state.methods):
             method.sampling_state = state_method
 
@@ -295,6 +311,33 @@ class CompoundStep(WithSamplingState):
         for method, _rng in zip(self.methods, _rngs):
             method.set_rng(_rng)
 
+    def _progressbar_config(self, n_chains=1):
+        from functools import reduce
+
+        column_lists, stat_dict_list = zip(
+            *[method._progressbar_config(n_chains) for method in self.methods]
+        )
+        flat_list = reduce(lambda left_list, right_list: left_list + right_list, column_lists)
+
+        columns = []
+        headers = []
+
+        for col in flat_list:
+            name = col.get_table_column().header
+            if name not in headers:
+                headers.append(name)
+                columns.append(col)
+
+        stats = reduce(lambda left_dict, right_dict: left_dict | right_dict, stat_dict_list)
+
+        return columns, stats
+
+    def _make_progressbar_update_functions(self):
+        update_functions = []
+        for method in self.methods:
+            update_functions.extend(method._make_progressbar_update_functions())
+        return update_functions
+
 
 def flatten_steps(step: BlockedStep | CompoundStep) -> list[BlockedStep]:
     """Flatten a hierarchy of step methods to a list."""
