@@ -63,7 +63,6 @@ from pytensor.graph.basic import Variable
 from pytensor.graph.replace import graph_replace
 from pytensor.scalar.basic import identity as scalar_identity
 from pytensor.tensor.elemwise import Elemwise
-from pytensor.tensor.shape import unbroadcast
 
 import pymc as pm
 
@@ -75,6 +74,7 @@ from pymc.model import modelcontext
 from pymc.pytensorf import (
     SeedSequenceSeed,
     compile,
+    constant_fold,
     find_rng_nodes,
     reseed_rngs,
 )
@@ -1096,13 +1096,6 @@ class Group(WithMemoization):
         """
         initial = self._new_initial(s, d, more_replacements)
         initial = pt.specify_shape(initial, self.symbolic_initial.type.shape)
-        # The static shape of initial may be more precise than self.symbolic_initial,
-        # and reveal previously unknown broadcastable dimensions. We have to mask those again.
-        if initial.type.broadcastable != self.symbolic_initial.type.broadcastable:
-            unbroadcast_axes = (
-                i for i, b in enumerate(self.symbolic_initial.type.broadcastable) if not b
-            )
-            initial = unbroadcast(initial, *unbroadcast_axes)
         if more_replacements:
             initial = graph_replace(initial, more_replacements, strict=False)
         return {self.symbolic_initial: initial}
@@ -1113,7 +1106,10 @@ class Group(WithMemoization):
         t = self.to_flat_input(
             pt.max(
                 [
-                    get_scaling(v.owner.inputs[1:], v.shape)
+                    get_scaling(
+                        v.owner.inputs[1:],
+                        constant_fold([v.owner.inputs[0].shape], raise_not_constant=False),
+                    )
                     for v in self.group
                     if isinstance(v.owner.op, MinibatchRandomVariable)
                 ]
@@ -1280,7 +1276,10 @@ class Approximation(WithMemoization):
         t = pt.max(
             self.collect("symbolic_normalizing_constant")
             + [
-                get_scaling(obs.owner.inputs[1:], obs.shape)
+                get_scaling(
+                    obs.owner.inputs[1:],
+                    constant_fold([obs.owner.inputs[0].shape], raise_not_constant=False),
+                )
                 for obs in self.model.observed_RVs
                 if isinstance(obs.owner.op, MinibatchRandomVariable)
             ]
